@@ -13,12 +13,12 @@ namespace GrantleeThemeEditor
 class ConfigureWidget;
 }
 
-namespace ContactEditor
+namespace Akonadi
 {
 class AkonadiContactEditor;
 }
 
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class PlainTextEditorWidget;
 }
@@ -36,6 +36,6 @@ private:
     void slotOkClicked();
     void slotDefaultClicked();
     GrantleeThemeEditor::ConfigureWidget *mConfigureWidget = nullptr;
-    KPIMTextEdit::PlainTextEditorWidget *mDefaultTemplate = nullptr;
-    ContactEditor::AkonadiContactEditor *mDefaultContact = nullptr;
+    TextCustomEditor::PlainTextEditorWidget *mDefaultTemplate = nullptr;
+    Akonadi::AkonadiContactEditor *mDefaultContact = nullptr;
 };
