@@ -10,6 +10,6 @@
 
 namespace DefaultCompletion
 {
-Q_REQUIRED_RESULT QStringList defaultCompetion();
-Q_REQUIRED_RESULT QStringList defaultOptions();
+[[nodiscard]] QStringList defaultCompetion();
+[[nodiscard]] QStringList defaultOptions();
 }
