@@ -15,13 +15,9 @@
 #include <QIcon>
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication app(argc, argv);
     app.setDesktopFileName(QStringLiteral("org.kde.contactprintthemeeditor"));
-    KLocalizedString::setApplicationDomain("contactprintthemeeditor");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("contactprintthemeeditor"));
     KAboutData aboutData(QStringLiteral("contactprintthemeeditor"),
                          i18n("Contact Print Theme Editor"),
                          QStringLiteral(GRANTLEEEDITOR_VERSION),
