@@ -20,7 +20,7 @@ ThemeTemplateListWidget::ThemeTemplateListWidget(const QString &configName, QWid
 
 ThemeTemplateListWidget::~ThemeTemplateListWidget() = default;
 
-QVector<PimCommon::defaultTemplate> ThemeTemplateListWidget::defaultTemplates()
+QList<PimCommon::defaultTemplate> ThemeTemplateListWidget::defaultTemplates()
 {
     return ThemeDefaultTemplate::defaultTemplates();
 }
@@ -38,3 +38,5 @@ ThemeTemplateWidget::ThemeTemplateWidget(const QString &title, QWidget *parent)
 }
 
 ThemeTemplateWidget::~ThemeTemplateWidget() = default;
+
+#include "moc_themetemplatewidget.cpp"
