@@ -16,7 +16,7 @@ public:
     explicit ThemeTemplateListWidget(const QString &configName, QWidget *parent = nullptr);
     ~ThemeTemplateListWidget() override;
 
-    Q_REQUIRED_RESULT QVector<PimCommon::defaultTemplate> defaultTemplates() override;
+    [[nodiscard]] QList<PimCommon::defaultTemplate> defaultTemplates() override;
 };
 
 class ThemeTemplateWidget : public QWidget
