@@ -10,7 +10,7 @@
 class QLineEdit;
 class KZip;
 class KEditListWidget;
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class PlainTextEditorWidget;
 }
@@ -30,11 +30,11 @@ public:
     void loadTheme(const QString &path);
 
     void setThemeName(const QString &themeName);
-    Q_REQUIRED_RESULT QString filename() const;
+    [[nodiscard]] QString filename() const;
 
-    Q_REQUIRED_RESULT QString description() const;
+    [[nodiscard]] QString description() const;
 
-    Q_REQUIRED_RESULT QString themeName() const;
+    [[nodiscard]] QString themeName() const;
     void createZip(const QString &themeName, KZip *zip);
     void installTheme(const QString &themePath);
     void setDefaultDesktopName(const QString &name);
@@ -50,7 +50,7 @@ private:
     void saveAsFilename(const QString &filename);
     QString mDefaultDesktopName;
     QLineEdit *mName = nullptr;
-    KPIMTextEdit::PlainTextEditorWidget *mDescription = nullptr;
+    TextCustomEditor::PlainTextEditorWidget *mDescription = nullptr;
     QLineEdit *mFilename = nullptr;
     QLineEdit *mAuthor = nullptr;
     QLineEdit *mEmail = nullptr;
