@@ -10,15 +10,15 @@
 #include <KSyntaxHighlighting/SyntaxHighlighter>
 #include <KSyntaxHighlighting/Theme>
 
-#include <KPIMTextEdit/TextEditorCompleter>
 #include <QAbstractItemView>
 #include <QCompleter>
 #include <QKeyEvent>
+#include <TextCustomEditor/TextEditorCompleter>
 
 using namespace GrantleeThemeEditor;
 
 GrantleePlainTextEditor::GrantleePlainTextEditor(QWidget *parent)
-    : KPIMTextEdit::PlainTextEditor(parent)
+    : TextCustomEditor::PlainTextEditor(parent)
 {
     const KSyntaxHighlighting::Definition def = mRepo.definitionForName(QStringLiteral("HTML"));
     if (!def.isValid()) {
@@ -37,7 +37,7 @@ GrantleePlainTextEditor::~GrantleePlainTextEditor() = default;
 
 void GrantleePlainTextEditor::initCompleter()
 {
-    mTextEditorCompleter = new KPIMTextEdit::TextEditorCompleter(this, this);
+    mTextEditorCompleter = new TextCustomEditor::TextEditorCompleter(this, this);
 }
 
 void GrantleePlainTextEditor::createCompleterList(const QStringList &extraCompletion)
@@ -60,6 +60,8 @@ void GrantleePlainTextEditor::keyPressEvent(QKeyEvent *e)
             break;
         }
     }
-    KPIMTextEdit::PlainTextEditor::keyPressEvent(e);
+    TextCustomEditor::PlainTextEditor::keyPressEvent(e);
     mTextEditorCompleter->completeText();
 }
+
+#include "moc_grantleeplaintexteditor.cpp"
