@@ -32,7 +32,7 @@ public:
     void uploadTheme();
     void installTheme(const QString &themePath);
 
-    Q_REQUIRED_RESULT bool themeWasChanged() const;
+    [[nodiscard]] bool themeWasChanged() const;
 
     void reloadConfig();
 
@@ -59,7 +59,7 @@ private:
     QString projectDirectory() const;
     void createZip(const QString &themeName, KZip *zip);
     EditorPage *createExtraPage(const QString &filename);
-    QVector<EditorPage *> mExtraPage;
+    QList<EditorPage *> mExtraPage;
     GrantleeThemeEditor::ThemeEditorTabWidget *mTabWidget = nullptr;
     EditorPage *mEditorPage = nullptr;
     GrantleeThemeEditor::DesktopFilePage *mDesktopPage = nullptr;
